eric6/PipInterface/PipPackagesWidget.py

changeset 7241
0c0c9015c40f
parent 7229
53054eb5b15a
child 7255
d595f6f9cbf8
--- a/eric6/PipInterface/PipPackagesWidget.py	Tue Sep 17 19:17:07 2019 +0200
+++ b/eric6/PipInterface/PipPackagesWidget.py	Tue Sep 17 19:20:18 2019 +0200
@@ -261,9 +261,9 @@
     @pyqtSlot(int)
     def on_environmentsComboBox_currentIndexChanged(self, index):
         """
         Private slot handling the selection of a conda environment.
         
-        @param index index of the selected conda environment
+        @param index index of the selected Python environment
         @type int
         """
         self.__refreshPackagesList()
@@ -261,9 +261,9 @@
     def on_environmentsComboBox_currentIndexChanged(self, index):
         """
-        Private slot handling the selection of a conda environment.
+        Private slot handling the selection of a Python environment.
         

eric ide

mercurial